@@ -1,7 +1,7 @@
 # fmt: off
 __title__ = "spacy"
-__version__ = "2.3.5"
-__release__ = True
+__version__ = "3.0.1"
 __download_url__ = "https://github.com/explosion/spacy-models/releases/download"
 __compatibility__ = "https://raw.githubusercontent.com/explosion/spacy-models/master/compatibility.json"
-__shortcuts__ = "https://raw.githubusercontent.com/explosion/spacy-models/master/shortcuts-v2.json"
+__projects__ = "https://github.com/explosion/projects"
+__projects_branch__ = "v3"
